==> scala-k8s-objects_sjs1_3-0.3.0-sources.jar: io/k8s/api/autoscaling/v2/HPAScalingPolicy.scala <==
package io.k8s.api.autoscaling.v2

import dev.hnaderi.k8s.utils._

/** HPAScalingPolicy is a single policy which must hold true for a specified past interval. */
final case class HPAScalingPolicy(
  periodSeconds : Int,
  `type` : String,
  value : Int
) {

  /** Returns a new data with periodSeconds set to new value */
  def withPeriodSeconds(value: Int) : HPAScalingPolicy = copy(periodSeconds = value)
  /** transforms periodSeconds to result of function */
  def mapPeriodSeconds(f: Int => Int) : HPAScalingPolicy = copy(periodSeconds = f(periodSeconds))

  /** Returns a new data with `type` set to new value */
  def withType(value: String) : HPAScalingPolicy = copy(`type` = value)
  /** transforms `type` to result of function */
  def mapType(f: String => String) : HPAScalingPolicy = copy(`type` = f(`type`))

  /** Returns a new data with value set to new value */
  def withValue(value: Int) : HPAScalingPolicy = copy(value = value)
  /** transforms value to result of function */
  def mapValue(f: Int => Int) : HPAScalingPolicy = copy(value = f(value))
}

object HPAScalingPolicy {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.autoscaling.v2.HPAScalingPolicy, T] = new Encoder[io.k8s.api.autoscaling.v2.HPAScalingPolicy, T] {
        def apply(o: io.k8s.api.autoscaling.v2.HPAScalingPolicy) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("periodSeconds", o.periodSeconds)
            .write("type", o.`type`)
            .write("value", o.value)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, HPAScalingPolicy] = new Decoder[T, HPAScalingPolicy] {
      def apply(t: T): Either[String, HPAScalingPolicy] = for {
          obj <- ObjectReader(t)
          periodSeconds <- obj.read[Int]("periodSeconds")
          `type` <- obj.read[String]("type")
          value <- obj.read[Int]("value")
      } yield HPAScalingPolicy (
          periodSeconds = periodSeconds,
          `type` = `type`,
          value = value
        )
    }
}

==> scala-k8s-objects_sjs1_3-0.5.1-sources.jar: io/k8s/api/autoscaling/v2/HPAScalingPolicy.scala <==
package io.k8s.api.autoscaling.v2

import dev.hnaderi.k8s.utils._

/** HPAScalingPolicy is a single policy which must hold true for a specified past interval. */
final case class HPAScalingPolicy(
  periodSeconds : Int,
  `type` : String,
  value : Int
) {

  /** Returns a new data with periodSeconds set to new value */
  def withPeriodSeconds(value: Int) : HPAScalingPolicy = copy(periodSeconds = value)
  /** transforms periodSeconds to result of function */
  def mapPeriodSeconds(f: Int => Int) : HPAScalingPolicy = copy(periodSeconds = f(periodSeconds))

  /** Returns a new data with `type` set to new value */
  def withType(value: String) : HPAScalingPolicy = copy(`type` = value)
  /** transforms `type` to result of function */
  def mapType(f: String => String) : HPAScalingPolicy = copy(`type` = f(`type`))

  /** Returns a new data with value set to new value */
  def withValue(value: Int) : HPAScalingPolicy = copy(value = value)
  /** transforms value to result of function */
  def mapValue(f: Int => Int) : HPAScalingPolicy = copy(value = f(value))
}

object HPAScalingPolicy {

    implicit val encoder : Encoder[io.k8s.api.autoscaling.v2.HPAScalingPolicy] = new Encoder[io.k8s.api.autoscaling.v2.HPAScalingPolicy] {
        def apply[T : Builder](o: io.k8s.api.autoscaling.v2.HPAScalingPolicy) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("periodSeconds", o.periodSeconds)
            .write("type", o.`type`)
            .write("value", o.value)
            .build
        }
    }

    implicit val decoder: Decoder[HPAScalingPolicy] = new Decoder[HPAScalingPolicy] {
      def apply[T : Reader](t: T): Either[String, HPAScalingPolicy] = for {
          obj <- ObjectReader(t)
          periodSeconds <- obj.read[Int]("periodSeconds")
          `type` <- obj.read[String]("type")
          value <- obj.read[Int]("value")
      } yield HPAScalingPolicy (
          periodSeconds = periodSeconds,
          `type` = `type`,
          value = value
        )
    }
}
